==> paraHaplo2.1.tar.gz: SNP/SNP_LIB/snp_Table.h <==
/************************************************************************/
/************************************************************************/
#ifndef __HEADER_FILE_TABLE__
#define __HEADER_FILE_TABLE__

typedef struct struct_SnpTable { 
	int *horizontalSum; /* isjƂ̍vBs̐vfz */
	int *verticalSum;   /* cijƂ̍vB̐vfz */
	int **table;
} SnpTable;

/* vg^Cv錾 */
int TableMain();
int TableInitTable(SnpTable *tbl);
int TableCreateTable(SnpTable *tbl, int numHori, int numVert);
int TableFinalTable(SnpTable *tbl);
int TableMakeTable4Int(SnpTable *tbl, int a1, int a2, int b1, int b2);
int TableMakeTableIntArray(SnpTable *tbl, int **T);
int **TableGetTable(SnpTable T);
int TableNewCandidate(SnpTable tbl, int a1, int **result);
int TableNewTable(SnpTable tbl, int a1, int **result);
int TableCalcL(SnpTable tbl);
int TableCalcU(SnpTable tbl);
double TableCalcPearsonScore(int **T);
int TableCalcV(SnpTable tbl, double Sobs);
int TableCalcW(SnpTable tbl, double Sobs);
double TableRootD(SnpTable tbl, double Sobs);
double TableDiscriminant(SnpTable tbl, double Sobs);
int TableTwoParts(SnpTable tbl, double Sobs);
double TableCalcFst(int **T);
void TableShowMatrix(int **data, int len1, int len2);
void TableShowVector(int *data, int len);
double TableCalcMu(int **T);
double TableCalcNu(int **T, double Sobs);
int TableInCj(double Sobs, int **T, int len1, int len2);
int TableJudgeCj(double Sobs, int **T, int len1, int len2);
double TableCalcR(int **T1, int len1, int len2, int **T2);
double TableCalcScore(int **T);
double TableCalcLogMu(int **T);
void TableMarkov1(SnpTable T, double Score, int **table);
void TableMarkov2(SnpTable T, double Score, int **table);
int TablePlusMinusOne();

#endif /* __HEADER_FILE_TABLE__ */

==> paraHaplo2.2.tar.gz: SNP/SNP_LIB/snp_Table.h <==
/************************************************************************/
/************************************************************************/
#ifndef __HEADER_FILE_TABLE__
#define __HEADER_FILE_TABLE__

typedef struct struct_SnpTable { 
	int *horizontalSum; /* ʹԡˤȤιסԤοǤ */
	int *verticalSum;   /* ˤȤιסοǤ */
	int **table;
} SnpTable;

/* ץȥ */
int TableMain();
int TableInitTable(SnpTable *tbl);
int TableCreateTable(SnpTable *tbl, int numHori, int numVert);
int TableFinalTable(SnpTable *tbl);
int TableMakeTable4Int(SnpTable *tbl, int a1, int a2, int b1, int b2);
int TableMakeTableIntArray(SnpTable *tbl, int **T);
int **TableGetTable(SnpTable T);
int TableNewCandidate(SnpTable tbl, int a1, int **result);
int TableNewTable(SnpTable tbl, int a1, int **result);
int TableCalcL(SnpTable tbl);
int TableCalcU(SnpTable tbl);
double TableCalcPearsonScore(int **T);
int TableCalcV(SnpTable tbl, double Sobs);
int TableCalcW(SnpTable tbl, double Sobs);
double TableRootD(SnpTable tbl, double Sobs);
double TableDiscriminant(SnpTable tbl, double Sobs);
int TableTwoParts(SnpTable tbl, double Sobs);
double TableCalcFst(int **T);
void TableShowMatrix(int **data, int len1, int len2);
void TableShowVector(int *data, int len);
double TableCalcMu(int **T);
double TableCalcNu(int **T, double Sobs);
int TableInCj(double Sobs, int **T, int len1, int len2);
int TableJudgeCj(double Sobs, int **T, int len1, int len2);
double TableCalcR(int **T1, int len1, int len2, int **T2);
double TableCalcScore(int **T);
double TableCalcLogMu(int **T);
void TableMarkov1(SnpTable T, double Score, int **table);
void TableMarkov2(SnpTable T, double Score, int **table);
int TablePlusMinusOne();

#endif /* __HEADER_FILE_TABLE__ */
